summaryrefslogtreecommitdiffstats
path: root/kandy/src/kandy.h
diff options
context:
space:
mode:
Diffstat (limited to 'kandy/src/kandy.h')
-rw-r--r--kandy/src/kandy.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/kandy/src/kandy.h b/kandy/src/kandy.h
index e2a7754b..a81208de 100644
--- a/kandy/src/kandy.h
+++ b/kandy/src/kandy.h
@@ -18,8 +18,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#ifndef KANDY_H
#define KANDY_H
@@ -48,6 +48,7 @@ class KandyPrefsDialog;
class Kandy : public KMainWindow
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Default Constructor
@@ -78,7 +79,7 @@ class Kandy : public KMainWindow
protected:
/**
* Overridden virtuals for Qt drag 'n drop (XDND)
*/
virtual void dragEnterEvent(TQDragEnterEvent *event);
virtual void dropEvent(TQDropEvent *event);
@@ -78,7 +79,7 @@ class Kandy : public KMainWindow
protected:
/**
- * Overridden virtuals for Qt drag 'n drop (XDND)
+ * Overridden virtuals for TQt drag 'n drop (XDND)
*/
virtual void dragEnterEvent(TQDragEnterEvent *event);